---
title: <span class="badge object-type-scalar"></span> MicroHenry
---
# <span class="badge object-type-scalar"></span> MicroHenry

Energy: Microhenry (µH)

## Definition

```python
# Energy: Microhenry (µH)
MicroHenry: typing.Literal["µhenry"] = "µhenry"
```
